@@ -368,7 +368,7 @@ impl<'a, T: Float, const MAXDIMS: usize> MulticubicRectilinearRecursive<'a, T, M
 
                 // Interpolate on next dim's values to populate an entry in this dim
                 let grid_cell = &self.grids[next_dim][origin[next_dim]..origin[next_dim] + 4];
-                interp_inner::<T, MAXDIMS>(
+                interp_inner::<T>(
                     vals,
                     grid_cell,
                     x[next_dim],
@@ -382,7 +382,7 @@ impl<'a, T: Float, const MAXDIMS: usize> MulticubicRectilinearRecursive<'a, T, M
 
 /// Calculate slopes and offsets & select evaluation method
 #[inline]
-fn interp_inner<T: Float, const MAXDIMS: usize>(
+fn interp_inner<T: Float>(
     vals: [T; 4],
     grid_cell: &[T],
     x: T,
@@ -440,7 +440,11 @@ fn interp_inner<T: Float, const MAXDIMS: usize>(
             let h12 = grid_cell[2] - grid_cell[1];
             let k0 =
                 -centered_difference_nonuniform(vals[0], vals[1], vals[2], T::one(), h12 / h01);
+
+            #[cfg(not(feature = "fma"))]
             let k1 = two * dy - k0; // Natural spline boundary condition
+            #[cfg(feature = "fma")]
+            let k1 = two.mul_add(dy, -k0); // Natural spline boundary condition
 
             let t = -(x - grid_cell[1]) / h01;
 
@@ -469,7 +473,14 @@ fn interp_inner<T: Float, const MAXDIMS: usize>(
             // If we are linearizing the interpolant under extrapolation,
             // hold the last slope outside the grid
             if linearize_extrapolation {
-                y1 + k1 * (t - one)
+                #[cfg(not(feature = "fma"))]
+                {
+                    y1 + k1 * (t - one)
+                }
+                #[cfg(feature = "fma")]
+                {
+                    k1.mul_add(t - one, y1)
+                }
             } else {
                 normalized_hermite_spline(t, y0, dy, k0, k1)
             }
@@ -484,7 +495,11 @@ fn interp_inner<T: Float, const MAXDIMS: usize>(
             let h12 = grid_cell[2] - grid_cell[1];
             let h23 = grid_cell[3] - grid_cell[2];
             let k0 = centered_difference_nonuniform(vals[1], vals[2], vals[3], h12 / h23, T::one());
+
+            #[cfg(not(feature = "fma"))]
             let k1 = two * dy - k0; // Natural spline boundary condition
+            #[cfg(feature = "fma")]
+            let k1 = two.mul_add(dy, -k0); // Natural spline boundary condition
 
             let t = (x - grid_cell[2]) / h23;
 
@@ -508,7 +523,14 @@ fn interp_inner<T: Float, const MAXDIMS: usize>(
             // If we are linearizing the interpolant under extrapolation,
             // hold the last slope outside the grid
             if linearize_extrapolation {
-                y1 + k1 * (t - one)
+                #[cfg(not(feature = "fma"))]
+                {
+                    y1 + k1 * (t - one)
+                }
+                #[cfg(feature = "fma")]
+                {
+                    k1.mul_add(t - one, y1)
+                }
             } else {
                 normalized_hermite_spline(t, y0, dy, k0, k1)
             }
